import React, { useState } from 'react'
import { useDrop } from 'react-dnd'
import { Icon, Button } from 'antd'
import { is, fromJS } from 'immutable'
import update from 'immutability-helper'
import Card from './card'
import ItemTypes from './itemtypes'
import './index.scss'

const Container = ({dict, list, handlePreviewList, handleMenu, deleteMemu, handleButton }) => {
  const [cards, setCards] = useState(list)
  const moveCard = (id, atIndex) => {
    const { card, index } = findCard(id)
    const _cards = update(cards, { $splice: [[index, 1], [atIndex, 0, card]] })
    setCards(_cards)
    handlePreviewList(_cards)
  }

  if (!is(fromJS(cards), fromJS(list))) {
    setCards(list)
  }

  const findCard = id => {
    const card = cards.filter(c => c.MenuID === id)[0]
    return {
      card,
      index: cards.indexOf(card),
    }
  }

  const editCard = id => {
    const { card, index } = findCard(id)
    handleMenu({
      card,
      index,
      type: 'edit'
    })
  }

  const delCard = id => {
    const { card } = findCard(id)
    deleteMemu(card)
  }

  const add = () => {
    handleButton('add')
  }
  
  const confirm = () => {
    handleButton('confirm')
  }

  const cancel = () => {
    handleButton('cancel')
  }

  const thawmenu = () => {
    handleButton('thawmenu')
  }

  const [, drop] = useDrop({ accept: ItemTypes.CARD })
  return (
    <div ref={drop} className="dragdashboard">
      {cards.map(card => (
        <Card
          key={card.MenuID}
          id={`${card.MenuID}`}
          text={card.MenuName}
          moveCard={moveCard}
          editCard={editCard}
          delCard={delCard}
          findCard={findCard}
        />
      ))}
      <div className="card-add" onClick={add}>
        <Icon type="plus" />
      </div>
      <Button type="primary" onClick={thawmenu}>{dict['model.thaw'] + dict['model.menu']}</Button>
      <Button type="primary" onClick={confirm}>{dict['model.confirm']}</Button>
      <Button onClick={cancel}>{dict['model.close']}</Button>
    </div>
  )
}
export default Container
